Index: src/arm/macro-assembler-arm.h |
=================================================================== |
--- src/arm/macro-assembler-arm.h (revision 3935) |
+++ src/arm/macro-assembler-arm.h (working copy) |
@@ -333,7 +333,6 @@ |
void StubReturn(int argc); |
// Call a runtime routine. |
- // Eventually this should be used for all C calls. |
void CallRuntime(Runtime::Function* f, int num_arguments); |
// Convenience function: Same as above, but takes the fid instead. |
@@ -344,14 +343,19 @@ |
int num_arguments); |
// Tail call of a runtime routine (jump). |
// Like JumpToRuntime, but also takes care of passing the number |
// of parameters. |
- void TailCallRuntime(const ExternalReference& ext, |
+ void TailCallExternalReference(const ExternalReference& ext, |
+ int num_arguments, |
+ int result_size); |
+ |
+ // Convenience function: tail call a runtime routine (jump). |
+ void TailCallRuntime(Runtime::FunctionId fid, |
int num_arguments, |
int result_size); |
// Jump to a runtime routine. |
- void JumpToRuntime(const ExternalReference& builtin); |
+ void JumpToExternalReference(const ExternalReference& builtin); |
// Invoke specified builtin JavaScript function. Adds an entry to |
// the unresolved list if the name does not resolve. |
@@ -344,14 +343,19 @@ |
int num_arguments); |
// Tail call of a runtime routine (jump). |
- // Like JumpToRuntime, but also takes care of passing the number |
+ // Like JumpToExternalReference, but also takes care of passing the number |
// of parameters. |